@@ -67,7 +67,7 @@ def get_credentials(args: Namespace) -> Tuple[str, int, str]:
     return (host, port, passwd)
 
 
-def main():
+def main() -> None:
     """Runs the RCON client."""
 
     args = get_args()
